import httpx
from httpx import Timeout

from stigg.generated.async_client import AsyncClient
from stigg.generated.client import Client

PRODUCTION_API_URL = "https://api.stigg.io/graphql"

DEFAULT_REQUEST_TIMEOUT = Timeout(timeout=30.0)

HTTP_TRANSPORT_RETRY_COUNT = 5


class StiggClient(Client):
    pass


class AsyncStiggClient(AsyncClient):
    pass


def get_headers(api_key: str):
    return {"X-API-KEY": api_key, "Content-Type": "application/json"}


class Stigg:
    @staticmethod
    def create_client(api_key: str, api_url: str = PRODUCTION_API_URL) -> StiggClient:
        headers = get_headers(api_key)
        transport = httpx.HTTPTransport(retries=HTTP_TRANSPORT_RETRY_COUNT)
        http_client = httpx.Client(
            headers=headers,
            timeout=DEFAULT_REQUEST_TIMEOUT,
            transport=transport
        )
        return StiggClient(
            url=api_url,
            headers=headers,
            http_client=http_client,
        )

    @staticmethod
    def create_async_client(
            api_key: str, api_url: str = PRODUCTION_API_URL
    ) -> AsyncStiggClient:
        headers = get_headers(api_key)
        transport = httpx.AsyncHTTPTransport(retries=HTTP_TRANSPORT_RETRY_COUNT)
        http_client = httpx.AsyncClient(
            headers=headers,
            timeout=DEFAULT_REQUEST_TIMEOUT,
            transport=transport
        )
        return AsyncStiggClient(
            url=api_url,
            headers=headers,
            http_client=http_client,
        )



# Generated by ariadne-codegen on 2023-07-13 16:02
# Source: operations.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import SubscriptionDecisionStrategy
from .fragments import SlimCustomerFragment, SlimSubscriptionFragment


class ProvisionCustomer(BaseModel):
    provision_customer: "ProvisionCustomerProvisionCustomer" = Field(
        alias="provisionCustomer"
    )


class ProvisionCustomerProvisionCustomer(BaseModel):
    customer: "ProvisionCustomerProvisionCustomerCustomer"
    subscription_decision_strategy: SubscriptionDecisionStrategy = Field(
        alias="subscriptionDecisionStrategy"
    )
    subscription: Optional["ProvisionCustomerProvisionCustomerSubscription"]


class ProvisionCustomerProvisionCustomerCustomer(SlimCustomerFragment):
    pass


class ProvisionCustomerProvisionCustomerSubscription(SlimSubscriptionFragment):
    pass


ProvisionCustomer.update_forward_refs()
ProvisionCustomerProvisionCustomer.update_forward_refs()
ProvisionCustomerProvisionCustomerCustomer.update_forward_refs()
ProvisionCustomerProvisionCustomerSubscription.update_forward_refs()



# Generated by ariadne-codegen on 2023-07-13 16:02
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import SubscriptionPreviewFragment


class EstimateSubscriptionUpdate(BaseModel):
    estimate_subscription_update: "EstimateSubscriptionUpdateEstimateSubscriptionUpdate" = Field(
        alias="estimateSubscriptionUpdate"
    )


class EstimateSubscriptionUpdateEstimateSubscriptionUpdate(SubscriptionPreviewFragment):
    pass


EstimateSubscriptionUpdate.update_forward_refs()
EstimateSubscriptionUpdateEstimateSubscriptionUpdate.update_forward_refs()
